@@ -1,13 +1,13 @@
 package Device::Firewall::PaloAlto;
-$Device::Firewall::PaloAlto::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
 use parent 'Device::Firewall::PaloAlto::API';
 
 use Device::Firewall::PaloAlto::Op;
-use Device::Firewall::PaloAlto::UserID;
 
 # VERSION
 # PODNAME
@@ -15,12 +15,6 @@ use Device::Firewall::PaloAlto::UserID;
 
 
 
-sub vsys {
-    my $self = shift;
-    ($self->{vsys_id}) = @_;
-}
-
-
 
 sub op {
     my $self = shift;
@@ -29,12 +23,6 @@ sub op {
 }
 
 
-sub user_id {  
-    my $self = shift;
-    return Device::Firewall::PaloAlto::UserID->_new($self);
-}
-
-
 1;
 
 __END__
@@ -49,7 +37,7 @@ Device::Firewall::PaloAlto - Interact with the Palo Alto firwall API
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
@@ -105,10 +93,6 @@ This function authenticates the credentials passed to new against the firewall.
 
 If successful, it returns the object itself to all method calls to be chains. If unsuccessful, it returns a L<Class::Error> object.
 
-=head2 vsys
-
-Sets the virtual system (vsys) ID to which calls will be applied. By default vsys 1 is used.
-
 =head2 op
 
 Returns a L<Device::Firewall::PaloAlto::Op> object. This object has methods to perform operational tasks on the firewall.
@@ -124,8 +108,6 @@ Returns a L<Device::Firewall::PaloAlto::Op> object. This object has methods to p
     # Returns the routes in the guest_vr virtual router
     my $routes = $fw->op->virtual_router('guest_vr');
 
-=head2 user_id
-
 =head2 Errors
 
 Errors are handled differently depending on whether the script is running from a file, or from a 'one-liner'.
