@@ -1,13 +1,14 @@
 package Device::Firewall::PaloAlto::API;
-$Device::Firewall::PaloAlto::API::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::API::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::API::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
 use URI;
 use Carp;
 use LWP::UserAgent;
-use HTTP::Request::Common;
+use HTTP::Request;
 use XML::Twig;
 use Class::Error;
 use Hook::LexWrap;
@@ -48,7 +49,6 @@ sub new {
     $object{uri} = $uri;
     $object{user_agent} = LWP::UserAgent->new(ssl_opts => $ssl_opts);
     $object{api_key} = '';
-    $object{vsys_id} = 1;
 
     return bless \%object, $class;
 }
@@ -105,12 +105,14 @@ sub _send_request {
     # If we're authenticated, add the API key
     $query{key} = $self->{api_key} if $self->{api_key};
 
-    # Create the request and pass it to the raw request function.
-    # This function exists to allow us to wrap it in debug functions
-    # and see the raw requests and responses
-    my $request = POST $self->{uri}->as_string, [ %query ];
-    my $response = $self->_send_raw_request($request);
-    
+    # Build the URI query section
+    my $uri = $self->{uri};
+    $uri->query_form( \%query );
+
+    # Create and send the HTTP::Request
+    my $http_request = HTTP::Request->new(GET => $uri->as_string);
+    my $response = $self->_send_raw_request($http_request);
+
     # Check and return
     return _parse_and_check_response( $response );
 }
@@ -196,7 +198,7 @@ Device::Firewall::PaloAlto::API - Palo Alto firewall API module
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 DESCRIPTION
 
