@@ -1,6 +1,7 @@
 package Device::Firewall::PaloAlto::Errors;
-$Device::Firewall::PaloAlto::Errors::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::Errors::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::Errors::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
@@ -19,8 +20,6 @@ use Carp;
 
 sub ERROR {
     my ($errstring, $errno) = @_;
-
-    $errno //= 0;
     
     # Are we in a one liner? If so, we croak out straight away
     my ($sub, $file, $inc);
@@ -47,7 +46,7 @@ Device::Firewall::PaloAlto::Errors - Parent class for errors.
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
