@@ -1,6 +1,7 @@
 package Device::Firewall::PaloAlto::JSON;
-$Device::Firewall::PaloAlto::JSON::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::JSON::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::JSON::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
@@ -55,7 +56,7 @@ Device::Firewall::PaloAlto::JSON - JSON parent class for Device::Firewall::PaloA
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
