@@ -1,6 +1,7 @@
 package Device::Firewall::PaloAlto::Op::Interface;
-$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
@@ -40,7 +41,7 @@ Device::Firewall::PaloAlto::Op::Interface - Palo Alto firewall interface
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
