@@ -1,6 +1,7 @@
 package Device::Firewall::PaloAlto::Op::Interfaces;
-$Device::Firewall::PaloAlto::Op::Interfaces::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::Op::Interfaces::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::Op::Interfaces::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
@@ -94,7 +95,7 @@ Device::Firewall::PaloAlto::Op::Interfaces - new module
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
