@@ -1,6 +1,7 @@
 package Device::Firewall::PaloAlto::Op::Tunnels;
-$Device::Firewall::PaloAlto::Op::Tunnels::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::Op::Tunnels::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::Op::Tunnels::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
@@ -59,7 +60,7 @@ Device::Firewall::PaloAlto::Op::Tunnels - Palo Alto IPSEC security associations
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
