@@ -1,6 +1,7 @@
 package Device::Firewall::PaloAlto::Op::VirtualRouter;
-$Device::Firewall::PaloAlto::Op::VirtualRouter::VERSION = '0.1.4';
-use strict;
+$Device::Firewall::PaloAlto::Op::VirtualRouter::VERSION = '0.1.4_1'; # TRIAL
+
+$Device::Firewall::PaloAlto::Op::VirtualRouter::VERSION = '0.1.41';use strict;
 use warnings;
 use 5.010;
 
@@ -78,7 +79,7 @@ Device::Firewall::PaloAlto::Op::VirtualRouter - new module
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.4_1
 
 =head1 SYNOPSIS
 
